pub struct DeploymentTarget {
pub major: u16,
pub minor: u8,
pub patch: u8,
}Expand description
The minimum OS version that we’re compiling for.
This is formatted as "major.minor.patch".
The size of the parts here are limited by Mach-O’s LC_BUILD_VERSION.
Fields
major: u16minor: u8patch: u8Trait Implementations
Sourceimpl Clone for DeploymentTarget
impl Clone for DeploymentTarget
Sourcefn clone(&self) -> DeploymentTarget
fn clone(&self) -> DeploymentTarget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeploymentTarget
Sourceimpl Debug for DeploymentTarget
impl Debug for DeploymentTarget
impl Eq for DeploymentTarget
Sourceimpl Hash for DeploymentTarget
impl Hash for DeploymentTarget
Sourceimpl Ord for DeploymentTarget
impl Ord for DeploymentTarget
Sourcefn cmp(&self, other: &DeploymentTarget) -> Ordering
fn cmp(&self, other: &DeploymentTarget) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeploymentTarget
impl PartialEq for DeploymentTarget
Sourcefn eq(&self, other: &DeploymentTarget) -> bool
fn eq(&self, other: &DeploymentTarget) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeploymentTarget
impl PartialOrd for DeploymentTarget
impl StructuralPartialEq for DeploymentTarget